import random
import string as a

def generate_pass():
    c = random.randint(6, 12)
    d = a.ascii_lowercase
    e = a.ascii_uppercase
    f = a.digits
    g = random.choice(d) + random.choice(e) + random.choice(f)
    h = ''.join(random.choices(d + e + f, k=c - 3))
    i = list(g + h)
    random.shuffle(i)
    j = ''.join(i)
    return j

#k = generate_pass()
#print(k)



import setuptools
from version import __version__

setuptools.setup(
    name="newPassword",
    version=__version__,
    author="Nipun Dogra",
    description="Password generator package",
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[]
)

